@@ -1,5 +1,16 @@
 #pragma once
 
+#ifdef WIN32
+#	define PRId64 "I64d"
+#	define PRIu64 "I64u"
+#	define PGRN_PRIdSIZE "Id"
+#	define PGRN_PRIuSIZE "Iu"
+#else
+#	include <inttypes.h>
+#	define PGRN_PRIdSIZE "zd"
+#	define PGRN_PRIuSIZE "zu"
+#endif
+
 #ifdef GP_VERSION
 #	define PGRN_IS_GREENPLUM
 #endif
@@ -159,3 +170,11 @@
 #	define PGRN_INDEX_AM_ROUTINE_HAVE_AM_PARALLEL_RESCAN
 #	define PGRN_SUPPORT_LOGICAL_REPLICATION
 #endif
+
+#if PG_VERSION_NUM >= 90500
+#	define pgrn_array_create_iterator(array, slide_ndim)	\
+	array_create_iterator(array, slide_ndim, NULL)
+#else
+#	define pgrn_array_create_iterator(array, slide_ndim)	\
+	array_create_iterator(array, slide_ndim)
+#endif
