@@ -8,13 +8,6 @@
 #include "pgrn-wal.h"
 #include "pgrn-writable.h"
 
-#ifdef WIN32
-#	define PRId64 "I64d"
-#	define PRIu64 "I64u"
-#else
-#	include <inttypes.h>
-#endif
-
 static bool PGrnWALEnabled = false;
 
 bool
@@ -406,6 +399,8 @@ PGrnWALStart(Relation index)
 	if (!RelationIsValid(index))
 		return NULL;
 
+	LockRelation(index, ShareUpdateExclusiveLock);
+
 	data = palloc(sizeof(PGrnWALData));
 
 	data->index = index;
@@ -437,6 +432,8 @@ PGrnWALFinish(PGrnWALData *data)
 	}
 	UnlockReleaseBuffer(data->meta.buffer);
 
+	UnlockRelation(data->index, ShareUpdateExclusiveLock);
+
 	pfree(data);
 #endif
 }
@@ -456,6 +453,8 @@ PGrnWALAbort(PGrnWALData *data)
 	}
 	UnlockReleaseBuffer(data->meta.buffer);
 
+	UnlockRelation(data->index, ShareUpdateExclusiveLock);
+
 	pfree(data);
 #endif
 }
@@ -1921,13 +1920,13 @@ PGrnWALApply(Relation index)
 	if (!PGrnWALApplyNeeded(&data))
 		return 0;
 
-	LockRelation(index, RowExclusiveLock);
+	LockRelation(index, ShareUpdateExclusiveLock);
 	PGrnIndexStatusGetWALAppliedPosition(data.index,
 										 &(data.current.block),
 										 &(data.current.offset));
 	data.sources = NULL;
 	nAppliedOperations = PGrnWALApplyConsume(&data);
-	UnlockRelation(index, RowExclusiveLock);
+	UnlockRelation(index, ShareUpdateExclusiveLock);
 #endif
 	return nAppliedOperations;
 }
@@ -2063,11 +2062,11 @@ PGrnWALTruncate(Relation index)
 	BlockNumber nBlocks;
 	GenericXLogState *state;
 
-	LockRelation(index, RowExclusiveLock);
+	LockRelation(index, ShareUpdateExclusiveLock);
 	nBlocks = RelationGetNumberOfBlocks(index);
 	if (nBlocks == 0)
 	{
-		UnlockRelation(index, RowExclusiveLock);
+		UnlockRelation(index, ShareUpdateExclusiveLock);
 		return 0;
 	}
 
@@ -2109,12 +2108,12 @@ PGrnWALTruncate(Relation index)
 
 	GenericXLogFinish(state);
 
-	UnlockRelation(index, RowExclusiveLock);
-
 	PGrnIndexStatusSetWALAppliedPosition(index,
 										 PGRN_WAL_META_PAGE_BLOCK_NUMBER + 1,
 										 0);
 
+	UnlockRelation(index, ShareUpdateExclusiveLock);
+
 	return nTruncatedBlocks;
 }
 #endif
